
# Slot: slots


list of slot names that are applicable to a class

URI: [linkml:slots](https://w3id.org/linkml/slots)


## Domain and Range

class_definition &#8594;  <sub>0..\*</sub> slot_definition

## Parents


## Children


## Used by

 * class_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | This defines the set of slots that are allowed to be used for a given class. The final list of slots for a class is the combination of the parent (is a) slots, mixins slots, apply to slots minus the slot usage entries. Formally, |

